==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/fa/fa5ecf4fe77b500084be2a5cc8d42f08.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-wien/assets/yt-white.png */
class __TwigTemplate_e8556912e62b0191ad6fe9738e0bb478 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000/\000\000\000sRGB\000\000\000\000eXIfMM\000*\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000J\000\000\000\000\000\000\000R(\000\000\000\000\000\000\000i\000\000\000\000\000\000\000Z\000\000\000\000\0007\000\000\tl\0007\000\000\tl\000\000\000\000\000\0000210\000\000\000\000\000\000\000\000\000\0000100\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000P[\000\000\000\tpHYs\000\000\000\000~\000\000TiTXtXML:com.adobe.xmp\000\000\000\000\000<x:xmpmeta xmlns:x=\"adobe:ns:meta/\" x:xmptk=\"XMP Core 6.0.0\">
   <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">
      <rdf:Description rdf:about=\"\"
            xmlns:tiff=\"http://ns.adobe.com/tiff/1.0/\"
            xmlns:exif=\"http://ns.adobe.com/exif/1.0/\">
         <tiff:YResolution>173623/2412</tiff:YResolution>
         <tiff:ResolutionUnit>2</tiff:ResolutionUnit>
         <tiff:XResolution>173623/2412</tiff:XResolution>
         <tiff:Orientation>1</tiff:Orientation>
         <exif:PixelXDimension>640</exif:PixelXDimension>
         <exif:ColorSpace>65535</exif:ColorSpace>
         <exif:ComponentsConfiguration>
            <rdf:Seq>
               <rdf:li>1</rdf:li>
               <rdf:li>2</rdf:li>
               <rdf:li>3</rdf:li>
               <rdf:li>0</rdf:li>
            </rdf:Seq>
         </exif:ComponentsConfiguration>
         <exif:ExifVersion>0210</exif:ExifVersion>
         <exif:FlashPixVersion>0100</exif:FlashPixVersion>
         <exif:PixelYDimension>447</exif:PixelYDimension>
      </rdf:Description>
   </rdf:RDF>
</x:xmpmeta>
;-\000\000
IDAT8jA5Ѱ\tz\t\$r|<-ɻ'Ac(WǍjb`6;v0_WuWOqfx\000Mp*d\\1Ŕyx}
~\000~PtHčz|?@iseٷ%lj+=2ߦ%vXl{y)i[N&-K<+j\tJ糋\$Z]/cLùC߲B<!LG_z1Yxؚxy6T>&h4X}sDOͱn?.vsj圠K}9.qLSpG;beM4wb}vaQ,Wu1]m<G=2JPď1nе?G<-pzHPaO,ea
SSZQV24_aeט<{
E`&&1SPf9not'.O,Ǒ\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-wien/assets/yt-white.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-wien/assets/yt-white.png", "/var/www/html/mauticGIT-Test/themes/fp-wien/assets/yt-white.png");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/fa/fa5ecf4fe77b500084be2a5cc8d42f08.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-wien/assets/yt-white.png */
class __TwigTemplate_e8556912e62b0191ad6fe9738e0bb478 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000/\000\000\000sRGB\000\000\000\000eXIfMM\000*\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000J\000\000\000\000\000\000\000R(\000\000\000\000\000\000\000i\000\000\000\000\000\000\000Z\000\000\000\000\0007\000\000\tl\0007\000\000\tl\000\000\000\000\000\0000210\000\000\000\000\000\000\000\000\000\0000100\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000P[\000\000\000\tpHYs\000\000\000\000~\000\000TiTXtXML:com.adobe.xmp\000\000\000\000\000<x:xmpmeta xmlns:x=\"adobe:ns:meta/\" x:xmptk=\"XMP Core 6.0.0\">
   <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">
      <rdf:Description rdf:about=\"\"
            xmlns:tiff=\"http://ns.adobe.com/tiff/1.0/\"
            xmlns:exif=\"http://ns.adobe.com/exif/1.0/\">
         <tiff:YResolution>173623/2412</tiff:YResolution>
         <tiff:ResolutionUnit>2</tiff:ResolutionUnit>
         <tiff:XResolution>173623/2412</tiff:XResolution>
         <tiff:Orientation>1</tiff:Orientation>
         <exif:PixelXDimension>640</exif:PixelXDimension>
         <exif:ColorSpace>65535</exif:ColorSpace>
         <exif:ComponentsConfiguration>
            <rdf:Seq>
               <rdf:li>1</rdf:li>
               <rdf:li>2</rdf:li>
               <rdf:li>3</rdf:li>
               <rdf:li>0</rdf:li>
            </rdf:Seq>
         </exif:ComponentsConfiguration>
         <exif:ExifVersion>0210</exif:ExifVersion>
         <exif:FlashPixVersion>0100</exif:FlashPixVersion>
         <exif:PixelYDimension>447</exif:PixelYDimension>
      </rdf:Description>
   </rdf:RDF>
</x:xmpmeta>
;-\000\000
IDAT8jA5Ѱ\tz\t\$r|<-ɻ'Ac(WǍjb`6;v0_WuWOqfx\000Mp*d\\1Ŕyx}
~\000~PtHčz|?@iseٷ%lj+=2ߦ%vXl{y)i[N&-K<+j\tJ糋\$Z]/cLùC߲B<!LG_z1Yxؚxy6T>&h4X}sDOͱn?.vsj圠K}9.qLSpG;beM4wb}vaQ,Wu1]m<G=2JPď1nе?G<-pzHPaO,ea
SSZQV24_aeט<{
E`&&1SPf9not'.O,Ǒ\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-wien/assets/yt-white.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-wien/assets/yt-white.png", "/var/www/mautic-ktn/themes/fp-wien/assets/yt-white.png");
    }
}
